Coverage for /home/delusionalinsanity/bbrepos/matyan/src/matyan/helpers.py: 100%

# Coverage for /home/delusionalinsanity/bbrepos/matyan/src/matyan/helpers.py : 100%

## 7 statements 7 run 0 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 | import os __author__ = 'Artur Barseghyan' __copyright__ = '2019 Artur Barseghyan' __license__ = 'GPL-2.0-only OR LGPL-2.0-or-later' __all__ = ( 'project_dir', ) def project_dir(base): """Absolute path to a file from current directory.""" return os.path.abspath( os.path.join(os.path.dirname(__file__), base).replace('\\', '/') )